<?php

namespace Fittest\Wordpress\Admin;

use Fittest\Fittest;
use Fittest\View;

class Experiment
{
    public function register()
    {
    	register_post_type('fittest_experiment', array(
			'labels' => array (
				'name' => __('Experiments', 'fittest'),
				'singular_name' => __('Experiment', 'fittest'),
				'add_new_item' => __('Add New Experiment', 'fittest'),
				'edit_item' => __('Edit Experiment', 'fittest'),
				'not_found' => __('No experiments found', 'fittest'),
			),
		    'public' => false,
		    'show_ui' => true,
		    'show_in_nav_menus' => true,
		    'menu_icon' => '',
		    'supports' => array(
		        'title'
		    )
		));
		
		add_action('save_post', array($this, 'save'));
		//add_action('wp_trash_post', array($this, 'trash'));
        add_filter('post_updated_messages', array($this, 'updated_messages'));
        
        add_filter( 'wp_get_nav_menu_items', array($this, 'exclude_menu_items'), null, 3 );
        
    }
    
	public function metabox()
	{
        add_meta_box(
            'fittest_experiment_data',
            __( 'Page Variations', 'fittest' ),
            array($this, 'variations'),
            'fittest_experiment'
        );
        
        add_meta_box(
            'fittest_experiment_stats',
            __( 'Statistics', 'fittest' ),
            array($this, 'statistics'),
            'fittest_experiment'//,
            //'side'
        );
        
        add_action('admin_footer', array($this, 'tooltips'));
    }
    
    public function variations($post)
    {
        $goals = get_post_meta( $post->ID, 'goals', true);

        // goal 0
        $goalid = 0;
        
        if (!isset($goals[$goalid]))
        {
            update_post_meta($post->ID, 'goals', array(array('pages' => array())));
            $goals = get_post_meta( $post->ID, 'goals', true);
        }
        
        $goal = $goals[$goalid];
        if (!is_array($goal))
        {
            $goal = array();
        }
        if (!isset($goal['pages']))
        {
            $goal['pages'] = array();
        }
        
        $pages = array();
        foreach(get_pages() as $page)
        {
            $pages[] = array(
                'id' => $page->ID,
                'title' => $page->post_title,
                'checked' => (in_array($page->ID, $goal['pages'])) ? 'checked' : ''
            );
        }
        
        print View::make('experiment/goal', compact('goalid', 'pages'));
    }
    
    public function statistics($post)
    {
        $goals = get_post_meta( $post->ID, 'goals', true);
        $list = Fittest::getPersistantExperiments();

        $data = array();
        if (isset($list[$post->ID]))
        {
            foreach($list[$post->ID] as $k => $v)
            {
                $page = get_post($k);
                $data[] = array(
                    $page->post_title, 
                    (isset($v['chosen'])) ? $v['chosen'] : 0,
                    (isset($v['awarded'])) ? $v['awarded'] : 0
                );
            }
            
            print View::make('experiment/statistics', compact('data'));
        }
        else
        {
            print __('No data found', 'fittest');
        }
    }
    
    public function save($post_id)
    {
        if (!isset($_POST['goals']))
        {
            return;
        }
    
        update_post_meta($post_id, 'goals', $_POST['goals']);
    }
    
    public function trash($post_id)
    {
        print $post_id;
        exit;
    }
    
    public function exclude_menu_items( $items, $menu, $args )
    {
        // Iterate over the items to search and destroy
        foreach ( $items as $key => $item ) 
        {
            //print_r($item);
            //if ( $item->object_id == 168 ) unset( $items[$key] );
        }

        return $items;
    }
    
    public function updated_messages($messages) 
    {
        $messages['post'][1] = __('<b>Experiment updated</b><br /> To make your experiment visible on your website please go to <span class="dashicons dashicons-admin-appearance"></span> <a href="'.admin_url('nav-menus.php').'">Appearance > Menus</a>, add the experiment to a menu and save it.', 'fittest');
        return $messages;
    }
    
    public function tooltips()
    {
        //print View::make('experiment/tooltips');
    }
}