<?php

namespace Fittest;

use Fittest\Algoritm\Algoritm;
use Fittest\Algoritm\MultiArmedBandit;
use Fittest\Algoritm\ABTesting;
use Fittest\Goal\Goal;
use Fittest\Variation\Variation;

class Experiment
{
    private $id;
    private $variations = array();
    private $algoritm;
    private $goals = array();
    private $chosen;
    
    protected function __construct($id)
    {
        $this->id = $id;
        $this->setAlgoritm(MultiArmedBandit::factory());
    }
    
    static public function factory($id)
    {
        return new self($id);
    }
    
    public function chooseVariation()
    {
        if ($this->chosen instanceof Variation)
        {
            return $this->chosen;    
        }
        $this->chosen = $this->getAlgoritm()->choose($this);
        return $this->chosen;
    }
    
    public function addVariation(Variation $variation)
    {
        $this->variations[$variation->getId()] = $variation;
    }
    
    public function countVariations()
    {
        return sizeof($this->variations);
    }
    
    public function getVariations()
    {
        return $this->variations;
    }
    
    public function getVariation($index)
    {
        $k = 0;
        foreach($this->variations as $variation)
        {
            if ($k == $index) break;
            $k++;
        }
        return $variation;
    }
    
    public function getAlgoritm()
    {
        return $this->algoritm;
    }
    
    public function setAlgoritm(Algoritm $algoritm)
    {
        $this->algoritm = $algoritm;
    }
    
    public function addGoal(Goal $goal)
    {
        $goal->setExperiment($this);
        $this->goals[$goal->getId()] = $goal;
    }
    
    public function getGoals()
    {
        return $this->goals;
    }
    
    public function getId()
    {
        return $this->id;
    }
}